@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2014-2021 Canonical, Ltd.
- * Copyright (C) 2021-2023 Colin Ian King.
+ * Copyright (C) 2021-2024 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -389,7 +389,7 @@ static int pid_max_digits(void)
 
 	buf[n] = '\0';
 	max_digits = 0;
-	while (buf[max_digits] >= '0' && buf[max_digits] <= '9')
+	while ((max_digits < n) && (buf[max_digits] >= '0') && (buf[max_digits] <= '9'))
 		max_digits++;
 	if (max_digits < min_digits)
 		max_digits = min_digits;
@@ -1241,8 +1241,8 @@ static void file_stat_dump(const double duration, const unsigned long top)
 	pid_size = pid_max_digits();
 	(void)printf("Total   Open  Close   Read  Write %*.*s  Process         %s%s\n",
 		pid_size, pid_size, "PID",
-		(opt_flags & OPT_INODE) ? "      Inode Device     Device Name" :
-		(opt_flags & OPT_DEVICE) ? "Device     Device Name" : "Pathname", ts);
+		(opt_flags & OPT_INODE) ? "      Inode Device     Name       " :
+		(opt_flags & OPT_DEVICE) ? "Device     Name       " : "Pathname", ts);
 	for (j = 0; j < file_stats_size; j++) {
 		if (top && j <= top) {
 			char buf[5][32];
